@@ -13,7 +13,7 @@ class Window(QWidget):
         super().__init__()
         # set widow titles
         self.setWindowTitle(' ')
-        self.setWindowIcon(QIcon('./images/title_logo.png'))
+        self.setWindowIcon(QIcon('synesthesia/images/title_logo.png'))
 
         # resize window
         self.resize(610, 580)
@@ -26,7 +26,7 @@ class Window(QWidget):
         self.logo.move(110, 0)
 
         # line seperators
-        sep = QPixmap('./images/line.png')
+        sep = QPixmap('synesthesia/images/line.png')
         sep = sep.scaled(610, 1)
         self.mid_line = QLabel(self)
         self.mid_line.setPixmap(sep)
@@ -160,11 +160,23 @@ class Window(QWidget):
         # Other Slider
         self.bs_lbl = QLabel(self)
 
-        print("jah test")
+        print("jah test43")
+
+        print(os.getcwd())
+
+        files = [f for f in os.listdir('.') if os.path.isfile(f)]
+        for f in files:
+            print(f)
+
+
+
         bsVar = "bleh"
-        with open("infile.txt", "rb") as file:
-            bsVar = file.read()
-            bsVar = str(bsVar, 'utf-8')
+        try:
+            with open("infile.txt", "rb") as file:
+                bsVar = file.read()
+                bsVar = str(bsVar, 'utf-8')
+        except ValueError:
+            print("nah")
 
         self.bs_lbl.setText(bsVar)
         self.bs_lbl.move(10, 350)
